@@ -18,13 +18,14 @@ import logging
 import threading
 import time
 
-import monasca_common.kafka_lib.client as kafka_client
-import monasca_common.kafka_lib.common as kafka_common
-import monasca_common.kafka_lib.consumer as kafka_consumer
-
 from kazoo.client import KazooClient
 from kazoo.recipe.partitioner import SetPartitioner
 
+import monasca_common.kafka_lib.client as kafka_client
+import monasca_common.kafka_lib.common as kafka_common
+from monasca_common.kafka_lib.conn import DEFAULT_SOCKET_TIMEOUT_SECONDS
+import monasca_common.kafka_lib.consumer as kafka_consumer
+
 log = logging.getLogger(__name__)
 
 """Kafka consumer interface
@@ -52,7 +53,8 @@ class KafkaConsumer(object):
                  fetch_size=1048576,
                  repartition_callback=None,
                  commit_callback=None,
-                 commit_timeout=30):
+                 commit_timeout=30,
+                 timeout=DEFAULT_SOCKET_TIMEOUT_SECONDS):
         """Init
 
              kafka_url            - Kafka location
@@ -68,6 +70,7 @@ class KafkaConsumer(object):
              commit_callback      - Callback to run when the commit_timeout
                                     has elapsed between commits.
              commit_timeout       - Timeout between commits.
+             timeout              - kafka connection timeout
         """
 
         self._kazoo_client = None
@@ -89,12 +92,18 @@ class KafkaConsumer(object):
         self._zookeeper_url = zookeeper_url
         self._zookeeper_path = zookeeper_path
 
-        self._kafka = kafka_client.KafkaClient(kafka_url)
+        self._kafka = kafka_client.KafkaClient(kafka_url, timeout=timeout)
 
         self._consumer = self._create_kafka_consumer()
 
     def _create_kafka_consumer(self, partitions=None):
         # No auto-commit so that commits only happen after the message is processed.
+
+        # auto_offset_reset is a param that alters where the current offset in the consumer
+        # will modify from (see whence param in SimpleConsumer.seek()). It is imperative to set
+        # this param as either "largest" or "smallest" depending on where we would like
+        # to modify the offset from, no matter what whence is set to.
+
         consumer = kafka_consumer.SimpleConsumer(
             self._kafka,
             self._kafka_group,
@@ -104,7 +113,8 @@ class KafkaConsumer(object):
             iter_timeout=5,
             fetch_size_bytes=self._kafka_fetch_size,
             buffer_size=self._kafka_fetch_size,
-            max_buffer_size=None)
+            max_buffer_size=None,
+            auto_offset_reset="smallest")
 
         consumer.provide_partition_info()
         consumer.fetch_last_known_offsets()
@@ -127,7 +137,7 @@ class KafkaConsumer(object):
             # an OffsetOutOfRangeError.  We trap this error and seek to
             # the head of the current Kafka data.  Because this error
             # only happens when Kafka removes data we're currently
-            # pointing at we're gauranteed that we won't read any
+            # pointing at we're guaranteed that we won't read any
             # duplicate data however we will lose any information
             # between our current offset and the new Kafka head.
 
