@@ -10,8 +10,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from __future__ import absolute_import
-
 import atexit
 import logging
 import time
@@ -94,7 +92,7 @@ def _send_upstream(queue, client, codec, batch_time, batch_size,
     while not stop_event.is_set():
         try:
             client.reinit()
-        except Exception as e:
+        except Exception:
             log.warn(
                 'Async producer failed to connect to brokers; backoff for %s(ms) before retrying',
                 retry_options.backoff_ms)
